==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebFilteringExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionDescription } from "./WebFilteringExpressionDescription";
/**
 * @hidden
 */
var WebFilteringExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFilteringExpressionDescriptionMetadata, _super);
    function WebFilteringExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFilteringExpressionDescriptionMetadata.b = function (a) {
        if (WebFilteringExpressionDescriptionMetadata.a == null) {
            WebFilteringExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFilteringExpressionDescriptionMetadata.c(WebFilteringExpressionDescriptionMetadata.a);
        }
        if (a.j(WebFilteringExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(WebFilteringExpressionDescriptionMetadata.a);
    };
    WebFilteringExpressionDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FilteringExpression");
        a.item("__packageNameWC", "String:grids");
    };
    WebFilteringExpressionDescriptionMetadata.d = function (a) {
        WebFilteringExpressionDescriptionMetadata.b(a);
        a.aa("WebFilteringExpression", function () { return new WebFilteringExpressionDescription(); });
        a.z("WebFilteringExpression", WebFilteringExpressionDescriptionMetadata.a);
    };
    WebFilteringExpressionDescriptionMetadata.$t = markType(WebFilteringExpressionDescriptionMetadata, 'WebFilteringExpressionDescriptionMetadata');
    WebFilteringExpressionDescriptionMetadata.a = null;
    return WebFilteringExpressionDescriptionMetadata;
}(Base));
export { WebFilteringExpressionDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebFilteringExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOperationDescriptionMetadata } from "./WebFilteringOperationDescriptionMetadata";
import { WebFilteringExpressionDescription } from "./WebFilteringExpressionDescription";
/**
 * @hidden
 */
var WebFilteringExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFilteringExpressionDescriptionMetadata, _super);
    function WebFilteringExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFilteringExpressionDescriptionMetadata.b = function (a) {
        if (WebFilteringExpressionDescriptionMetadata.a == null) {
            WebFilteringExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFilteringExpressionDescriptionMetadata.c(WebFilteringExpressionDescriptionMetadata.a);
        }
        if (a.k(WebFilteringExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebFilteringExpressionDescriptionMetadata.a);
        WebFilteringOperationDescriptionMetadata.d(a);
    };
    WebFilteringExpressionDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FilteringExpression");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("FieldName", "String");
        a.item("Condition", "ExportedType:WebFilteringOperation");
        a.item("SearchVal", "Unknown");
        a.item("IgnoreCase", "Boolean");
    };
    WebFilteringExpressionDescriptionMetadata.d = function (a) {
        WebFilteringExpressionDescriptionMetadata.b(a);
        a.ac("WebFilteringExpression", function () { return new WebFilteringExpressionDescription(); });
        a.ab("WebFilteringExpression", WebFilteringExpressionDescriptionMetadata.a);
    };
    WebFilteringExpressionDescriptionMetadata.$t = markType(WebFilteringExpressionDescriptionMetadata, 'WebFilteringExpressionDescriptionMetadata');
    WebFilteringExpressionDescriptionMetadata.a = null;
    return WebFilteringExpressionDescriptionMetadata;
}(Base));
export { WebFilteringExpressionDescriptionMetadata };
